KoolbaseBatchResult class

The result of one operation in a KoolbaseDatabaseClient.batch, in order.

Constructors

KoolbaseBatchResult({required String type, KoolbaseRecord? record, bool? created, bool deleted = false})
const
KoolbaseBatchResult.fromJson(Map<String, dynamic> json)
factory

Properties

created bool?
For upsert: true if a new record was inserted, false if one was updated. Null for non-upsert ops.
final
deleted bool
True for a successful delete.
final
hashCode int
The hash code for this object.
no setterinherited
record KoolbaseRecord?
The resulting record for insert/update/upsert; null for delete.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The operation type: insert, update, delete, or upsert.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited