KoolbaseCollection class

Constructors

KoolbaseCollection({required String id, required String projectId, required String name, required String readRule, required String writeRule, required String deleteRule, required DateTime createdAt})
const
KoolbaseCollection.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime
final
deleteRule String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
projectId String
final
readRule String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writeRule String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited