KoolbaseSemanticSearchResult class

Result of KoolbaseQuery.searchSemantic. hits is the ranked list of nearest neighbors (best match first); total is the count of hits returned (matches hits.length in v1 — preserved as a separate field for future pagination).

Constructors

KoolbaseSemanticSearchResult({required List<KoolbaseSemanticHit> hits, required int total})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hits List<KoolbaseSemanticHit>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited