KoolbaseVersionPolicy class

Version policy for forced/soft update enforcement.

Constructors

KoolbaseVersionPolicy({required String latestVersion, required String minVersion, required bool forceUpdate, required String updateMessage})
const
KoolbaseVersionPolicy.fromJson(Map<String, dynamic> json)
factory

Properties

forceUpdate bool
final
hashCode int
The hash code for this object.
no setterinherited
latestVersion String
final
minVersion String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateMessage String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

empty() KoolbaseVersionPolicy