RealtimeEvent class

Constructors

RealtimeEvent({required RealtimeEventType type, String? channel, Map<String, dynamic>? payload, required DateTime timestamp})
const
RealtimeEvent.fromJson(Map<String, dynamic> json)
factory

Properties

channel String?
final
collection String?
no setter
hashCode int
The hash code for this object.
no setterinherited
payload Map<String, dynamic>?
final
record Map<String, dynamic>?
no setter
recordId String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
type RealtimeEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited