UnlockTokenInvalidException class

Thrown when the unlock token (from a brute-force unlock email) is invalid or expired. Unlock tokens are one-shot — once consumed, the same token can't be reused.

Inheritance

Constructors

UnlockTokenInvalidException()
const

Properties

code String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited