Koolbase class
The main Koolbase SDK client.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- analytics → KoolbaseAnalyticsClient
-
no setter
- auth → KoolbaseAuthClient
-
Access the auth client
no setter
- codePush → KoolbaseCodePushClient
-
no setter
- db → KoolbaseDatabaseClient
-
Access the database client
no setter
- deviceId → String
-
no setter
- functions → KoolbaseFunctionsClient
-
Access the functions client
no setter
- messaging → KoolbaseMessaging
-
no setter
- payloadVersion → String
-
no setter
- realtime → KoolbaseRealtimeClient
-
Access the realtime client
no setter
- storage → KoolbaseStorageClient
-
Access the storage client
no setter
Static Methods
-
checkVersion(
) → VersionCheckResult -
configBool(
String key, {bool fallback = false}) → bool -
configDouble(
String key, {double fallback = 0.0}) → double -
configInt(
String key, {int fallback = 0}) → int -
configMap(
String key, {Map< String, dynamic> fallback = const {}}) → Map<String, dynamic> -
configString(
String key, {String fallback = ''}) → String -
executeFlow(
{required String flowId, Map< String, dynamic> ? context}) → FlowResult - Access the code push client Execute a named flow from the active bundle.
-
initialize(
KoolbaseConfig config) → Future< void> - Initializes the SDK. Call this in main() before runApp().
-
isEnabled(
String flagKey) → bool