KoolbaseRealtimeClient class
Constructors
-
KoolbaseRealtimeClient({required String baseUrl, required String publicKey, required Future<
String?> accessTokenProvider()})
Properties
-
accessTokenProvider
→ Future<
String?> Function() -
final
- baseUrl → String
-
final
-
connectionState
→ Stream<
bool> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- publicKey → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on(
{required String collection}) → Stream< RealtimeEvent> - Subscribe to a collection — returns a stream of realtime events. The project is taken from the signed-in user's session.
-
onRecordCreated(
{required String collection}) → Stream< Map< String, dynamic> > -
onRecordDeleted(
{required String collection}) → Stream< String> -
onRecordUpdated(
{required String collection}) → Stream< Map< String, dynamic> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited