KoolbaseStoragePermissionException class

Thrown when the caller is authenticated but not allowed to perform the storage operation — the server responds with 403.

Inheritance

Constructors

KoolbaseStoragePermissionException([String message = 'You do not have permission to perform this storage action'])
const

Properties

code String?
The server's stable error code, when present.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable message from the server (or a sensible default).
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited